###############################################################
#   
#  File:      lib_inc.rb
#
#  Author:    Christian Hättich
#
#  Project:   System-On-Chip Maker
#
#  Target:    Linux / Windows / Mac
#
#  Language:  ruby
#
#
###############################################################
#
#
#   Copyright (C) 2014  Christian Hättich  - feddischson [ at ] opencores.org
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
###############################################################
module SOCMaker


#
# A small class, which represents a library-include information.
# The included directories are stored in @dirs
#
#
#
class LibInc
  include ERR
  include YAML_EXT

  # the included directories
  attr_accessor :dirs

  #
  # This constructor does nothing special. The directories can be passed
  # via optional arguments
  #
  def initialize( opts = {} )
    init_with( opts )
  end

  # 
  # Encoder method (to yaml)
  #
  # +coder+:: An instance of the Psych::Coder to encode this class to a YAML file
  #
  def encode_with( coder )
    init_error_if !coder.is_a?( Psych::Coder ), 
                'coder is not given as Psych::Coder'
    %w[ dirs ].
      each { |v| coder[ v ] = instance_variable_get "@#{v}" }
  end

  #
  # Initialization method (from yaml)
  #
  # +coder+:: An instance of the Psych::Coder to init this class from a YAML file
  #
  #
  def init_with( coder )
    init_error_if !( coder.is_a?( Hash ) || coder.is_a?( Psych::Coder ) ), 
                'coder is not given as Hash neither as Psych::Coder'

    init_error 'no dirs are given' if coder[ 'dirs' ] == nil
    @dirs = coder[ 'dirs' ] 

    init_error 'dirs must be of type array' if  !@dirs.is_a?( Array )
    init_error 'there must be at least one dir-entry' if @dirs.size == 0


    @dirs.each do |f|
      init_error  "The dir must be defined as string",
        field: 'dirs' if !f.is_a?( String )

      init_error "The path string has zero length",
        field: 'dirs' if f.size == 0
    end
  end 


  #
  # Equality operator
  #
  def ==(o)
    o.class == self.class && o.dirs == self.dirs
  end

end
end

# vim: noai:ts=2:sw=2


